@@ -1,3 +1,12 @@
+"""
+These are conformance tests that ensure the output of quickdna matches biopython
+for randomly-generated strings of DNA.
+
+Hypothesis is a property testing library, which means it takes some schema, in
+our case valid DNA strings, and generates random data matching that schema in
+order to test certain assertions hold.
+"""
+
 from Bio.Seq import Seq
 from hypothesis import given, strategies as st
 
@@ -5,6 +14,7 @@ from quickdna import DnaSequence
 
 st_dna = st.text(alphabet=("a", "A", "t", "T", "c", "C", "g", "G"))
 
+
 @given(st_dna)
 def test_translate(dna):
     for table in range(1, 34):
@@ -15,6 +25,7 @@ def test_translate(dna):
             biopython_translation = bytes(Seq(dna).translate(table=table))
             assert quickdna_translation == biopython_translation
 
+
 @given(st_dna)
 def test_reverse_complement(dna):
     quickdna_rc = DnaSequence(dna).reverse_complement().seq
